@@ -9,8 +9,23 @@ from pinecone.specs.service import Service  # noqa
 from pinecone.specs.traffic_router import TrafficRouter  # noqa
 from pinecone.utils.sentry import sentry_decorator as sentry
 from .constants import Config
+from .manage import create_index, delete_index, describe_index, list_indexes, ResourceDescription
+from .index import Index, UpsertResult, DeleteResult, QueryResult, FetchResult, InfoResult
 
-__all__ = ["init"]
+__all__ = [
+    "init",
+    "create_index",
+    "delete_index",
+    "describe_index",
+    "list_indexes",
+    "ResourceDescription",
+    "Index",
+    "UpsertResult",
+    "DeleteResult",
+    "QueryResult",
+    "FetchResult",
+    "InfoResult",
+]
 
 logging_level = os.environ.get("PINECONE_LOGGING", default="ERROR")
 logger.remove()
@@ -21,7 +36,7 @@ __version__ = open(os.path.join(os.path.dirname(__file__), "__version__")).read(
 
 @sentry
 def init(api_key: str = None, host: str = None, environment: str = None, config: str = "~/.pinecone", **kwargs):
-    """Initializes Pinecone client.
+    """Initializes the Pinecone client.
 
     :param api_key: Required if not set in config file or by environment variable ``PINECONE_API_KEY``.
     :param host: Optional. Controller host.
