@@ -8,6 +8,7 @@ import numpy as np
 from pinecone.protos import core_pb2
 from pinecone.utils import load_numpy
 from pinecone.utils.sentry import sentry_decorator as sentry
+from pinecone.utils.progressbar import ProgressBar
 from .api_controller import ControllerAPI
 from .api_router import RouterAPI
 from .constants import Config
@@ -61,12 +62,15 @@ class CursorConfig(NamedTuple):
     :type parse_response_fn: Optional[Callable[["core_pb2.Request"], Iterable]], optional
     :param unary: send unary-unary gRPC requests. Defaults to `False`.
     :type unary: bool, optional
+    :param disable_progress_bar: disable progress bar. Defaults to `False`.
+    :type disable_progress_bar: bool
     """
 
     grpc_client: GRPCClient
     create_request_fn: Callable[[Iterable], "core_pb2.Request"]
     parse_response_fn: Optional[Callable[["core_pb2.Request"], Iterable]] = None
     unary: Optional[bool] = False
+    disable_progress_bar: bool = False
 
 
 class Cursor:
@@ -88,6 +92,7 @@ class Cursor:
         self.batch_size = batch_size or 100
         self._item_iterator = iter(items)
         self._unary = config.unary
+        self._disable_progress_bar = config.disable_progress_bar
         self._client = config.grpc_client
         self._create_reqeust_fn = config.create_request_fn
         self._parse_response_fn = config.parse_response_fn or self.identity
@@ -98,18 +103,32 @@ class Cursor:
 
         :param size: the number of items to process
         """
-        result = list(self._fetch_unbuffered(size=size))
-        return result or None
+        result = []
+        if self._disable_progress_bar:
+            result = list(self._fetch_unbuffered(size=size))
+        else:
+            result = list(ProgressBar.iter(self._fetch_unbuffered(size=size)))
+        return result
 
     @sentry
     def collect(self):
         """Processes all of the items and returns the results."""
-        return list(self._fetch_unbuffered())
+        result = []
+        if self._disable_progress_bar:
+            result = list(self._fetch_unbuffered())
+        else:
+            result = list(ProgressBar.iter(self._fetch_unbuffered()))
+        return result
 
     @sentry
     def stream(self) -> Iterator:
         """Processes all of the items, returns the results one batch at a time."""
-        return self._fetch_unbuffered()
+        ret_iter = None
+        if self._disable_progress_bar:
+            ret_iter = self._fetch_unbuffered()
+        else:
+            ret_iter = ProgressBar.iter(self._fetch_unbuffered())
+        return ret_iter
 
     def __iter__(self):
         raise RuntimeError(
@@ -159,7 +178,7 @@ class Cursor:
         batch = []
         for ii, item in enumerate(self._item_iterator):
             batch.append(item)
-            if len(batch) >= self.batch_size:
+            if len(batch) >= self.batch_size or (size and len(batch) >= size):
                 yield self._create_reqeust_fn(batch)
                 batch = []
             if not size:
@@ -185,8 +204,16 @@ class Connection:
     separate the recommendations by genre.
     """
 
-    def __init__(self, host: str, port: int, api_key: str = None, service_name: str = None, timeout: int = 0,
-                 response_timeout: int = 20, traceroute: bool = False):
+    def __init__(
+        self,
+        host: str,
+        port: int,
+        api_key: str = None,
+        service_name: str = None,
+        timeout: int = 0,
+        response_timeout: int = 20,
+        traceroute: bool = False,
+    ):
         """
         :param host: service host
         :type host: str
@@ -208,8 +235,15 @@ class Connection:
         self.port = port
         self.api_key = api_key
         self.service_name = service_name
-        self.grpc = GRPCClient(host=host, port=port, api_key=api_key, service_name=service_name, conn_timeout=timeout,
-                               timeout=response_timeout, traceroute=traceroute)
+        self.grpc = GRPCClient(
+            host=host,
+            port=port,
+            api_key=api_key,
+            service_name=service_name,
+            conn_timeout=timeout,
+            timeout=response_timeout,
+            traceroute=traceroute,
+        )
 
     @sentry
     def upsert(
@@ -257,13 +291,14 @@ class Connection:
     @sentry
     def unary_upsert(self, item: Tuple[str, np.ndarray], namespace: str = None) -> Optional[IndexResult]:
         """Inserts or updates an item.
-        
+
         This is the unary version of :py:meth:`upsert`, which upserts one item at a time.
         """
-        result = self.upsert(items=[item], namespace=namespace, cursor_config={"unary": True}).collect()
+        result = self.upsert(
+            items=[item], namespace=namespace, cursor_config={"unary": True, "disable_progress_bar": True}
+        ).collect()
         return result[0] if result else None
 
-
     @sentry
     def delete(
         self, ids: Iterable[str], namespace: str = None, batch_size: int = None, cursor_config: dict = None
@@ -300,13 +335,14 @@ class Connection:
     @sentry
     def unary_delete(self, id: str, namespace: str = None) -> Optional[DeleteResult]:
         """Deletes an item by its id.
-        
+
         This is the unary version of :py:meth:`delete`, which deletes one item at a time.
         """
-        result = self.delete(ids=[id], namespace=namespace, cursor_config={"unary": True}).collect()
+        result = self.delete(
+            ids=[id], namespace=namespace, cursor_config={"unary": True, "disable_progress_bar": True}
+        ).collect()
         return result[0] if result else None
 
-
     @sentry
     def fetch(
         self, ids: Iterable[str], namespace: str = None, batch_size: int = None, cursor_config: dict = None
@@ -346,13 +382,14 @@ class Connection:
     @sentry
     def unary_fetch(self, id: str, namespace: str = None) -> Optional[FetchResult]:
         """Fetches an item by its id.
-        
+
         This is the unary version of :py:meth:`fetch`, which fetches one item at a time.
         """
-        result = self.fetch(ids=[id], namespace=namespace, cursor_config={"unary": True}).collect()
+        result = self.fetch(
+            ids=[id], namespace=namespace, cursor_config={"unary": True, "disable_progress_bar": True}
+        ).collect()
         return result[0] if result else None
 
-
     @sentry
     def query(
         self,
@@ -412,15 +449,18 @@ class Connection:
         self, query: np.ndarray, namespace: str = None, top_k: int = 10, include_data: bool = False
     ) -> Optional[QueryResult]:
         """Sends a query.
-        
+
         This is the unary version of :py:meth:`query`, which sends one query at a time.
         """
         result = self.query(
-            queries=[query], namespace=namespace, top_k=top_k, include_data=include_data, cursor_config={"unary": True}
+            queries=[query],
+            namespace=namespace,
+            top_k=top_k,
+            include_data=include_data,
+            cursor_config={"unary": True, "disable_progress_bar": True},
         ).collect()
         return result[0] if result else None
 
-
     @sentry
     def info(self, namespace: str = None) -> Optional[InfoResult]:
         """Returns information of the index."""
@@ -433,9 +473,13 @@ class Connection:
             return [InfoResult(index_size=response.info.index_size)]
 
         cursor_config = CursorConfig(
-            grpc_client=self.grpc, create_request_fn=_create_info_request, parse_response_fn=_parse_info_response
+            grpc_client=self.grpc,
+            create_request_fn=_create_info_request,
+            parse_response_fn=_parse_info_response,
+            unary=True,
+            disable_progress_bar=True,
         )
-        result = Cursor(config=cursor_config, items=[1]).take(1)
+        result = Cursor(config=cursor_config, items=[1]).collect()
         return result[0] if result else None
 
     @sentry
@@ -451,8 +495,13 @@ class Connection:
 
 
 @sentry
-def connect(service_name: str = None, router_name: str = None, timeout: int = 0,
-            response_timeout: int = 20, traceroute: bool = False) -> Connection:
+def connect(
+    service_name: str = None,
+    router_name: str = None,
+    timeout: int = 0,
+    response_timeout: int = 20,
+    traceroute: bool = False,
+) -> Connection:
     """Connects to a live service/router and returns an instance of :class:`Connection`.
 
     :param service_name: name of a service.
@@ -480,5 +529,12 @@ def connect(service_name: str = None, router_name: str = None, timeout: int = 0,
 
     host = status.get("host") or Config.CONTROLLER_HOST.split("://")[1].split(":")[0]
     port = status.get("port")
-    return Connection(host=host, port=port, api_key=Config.API_KEY, service_name=dest_name,
-                      timeout=timeout, response_timeout=response_timeout, traceroute=traceroute)
+    return Connection(
+        host=host,
+        port=port,
+        api_key=Config.API_KEY,
+        service_name=dest_name,
+        timeout=timeout,
+        response_timeout=response_timeout,
+        traceroute=traceroute,
+    )
