@@ -15,5 +15,5 @@ if __name__ == '__main__':
 
     ZMQService.add_args(parser)
 
-    args = parser.parse_args()
+    args, unk = parser.parse_known_args()
     ZMQService.start_with_args(args)
