@@ -24,7 +24,7 @@ if __name__ == '__main__':
     parser = argparse.ArgumentParser(description='Load functions with config')
     functions.Function.add_args(parser)
 
-    args = parser.parse_args()
+    args, unk = parser.parse_known_args()
 
     model = importlib.import_module('model')
 
