@@ -14,6 +14,7 @@ from pinecone.functions.engine import namespaced
 from pinecone.functions.ranker import aggregator
 from pinecone.utils.sentry import sentry_decorator as sentry
 from pinecone.utils.constants import NodeType
+from typing import Dict, NamedTuple, Optional
 
 __all__ = ["Graph", "IndexGraph"]
 
@@ -97,6 +98,60 @@ class Graph(service_specs.Service):
         return graphviz.Source(nx.nx_pydot.to_pydot(graph))
 
 
+class IndexConfig(NamedTuple):
+    """Index configuration options.
+
+    :param engine_type: type of engine, one of {"approximated", "exact"}, defaults to "approximated".
+        The "approximated" engine uses fast approximate search algorithms developed by Pinecone.
+        The "exact" engine uses accurate exact search algorithms.
+        It performs exhaustive searches and thus it is usually slower than the "approximated" engine.
+    :type engine_type: str, optional
+    :param metric: type of metric used in the vector index, one of {"cosine", "dotproduct", "euclidean"}, defaults to "cosine".
+        Use "cosine" for cosine similarity,
+        "dotproduct" for dot-product,
+        and "euclidean" for euclidean distance.
+    :type metric: str, optional
+    :param shards: the number of shards for the engine, defaults to 1.
+        As a general guideline, use 1 shard per 1 GB of data.
+    :type shards: int, optional
+    :param replicas: the number of replicas, defaults to 1.
+        Use at least 2 replicas if you need high availability (99.99% uptime) for querying.
+        For additional throughput (QPS) your service needs to support, provision additional replicas.
+    :type replicas: int, optional
+    :param gateway_replicas: number of replicas of both the gateway and the aggregator.
+    :type gateway_replicas: int
+    :param engine_args: advanced arguments for the engine instance in the graph.
+    :type engine_args: dict
+    """
+    engine_type: str = "approximated"
+    metric: str = "cosine"
+    shards: int = 1
+    replicas: int = 1
+    gateway_replicas: int = 1
+    node_type: str = NodeType.STANDARD.value
+    engine_args: Optional[dict] = None
+
+    @classmethod
+    def _from_dict(cls, kwargs: dict):
+        cls_kwargs = {kk: vv for kk, vv in kwargs.items() if kk in cls._fields}
+        return cls(**cls_kwargs)
+
+    @classmethod
+    def _from_graph(cls, graph: Graph):
+        """Reconstruct configs from a Graph."""
+        config = {}
+        config["gateway_replicas"] = graph.gateway_replicas
+        engine = graph.functions.get("engine")
+        if engine:
+            config["replicas"] = engine.replicas
+            config["shards"] = engine.shards
+            config["node_type"] = engine._node_type.value
+            config["engine_type"] = engine.config.pop("engine_type")
+            config["metric"] = engine.config.pop("metric")
+            config["engine_args"] = {**(engine.config or {})}
+        return cls(**config)
+
+
 class IndexGraph(Graph):
     """The graphical representation of an index service.
 
@@ -113,32 +168,17 @@ class IndexGraph(Graph):
     _default_aggregator = aggregator.Aggregator
 
     @sentry
-    def __init__(self, engine_type: str = "approximated", metric: str = "cosine", shards: int = 1, replicas: int = 1,
-                 node_type: NodeType = NodeType.STANDARD, gateway_replicas: int = 1):
-        """
+    def __init__(self, **kwargs):
+        """See :class:`IndexConfig` for details about the parameters."""
+        config = IndexConfig._from_dict(kwargs)
+        engine_type = config.engine_type
+        metric = config.metric
+        shards = config.shards
+        replicas = config.replicas
+        gateway_replicas = config.gateway_replicas
+        node_type = NodeType(config.node_type)
+        engine_args = config.engine_args or {}
 
-        :param engine_type: type of engine, one of {"approximated", "exact"}, defaults to "approximated".
-            The "approximated" engine uses fast approximate search algorithms developed by Pinecone.
-            The "exact" engine uses accurate exact search algorithms.
-            It performs exhaustive searches and thus it is usually slower than the "approximated" engine.
-        :type engine_type: str, optional
-        :param metric: type of metric used in the vector index, one of {"cosine", "dotproduct", "euclidean"}, defaults to "cosine".
-            Use "cosine" for cosine similarity,
-            "dotproduct" for dot-product,
-            and "euclidean" for euclidean distance.
-        :type metric: str, optional
-        :param shards: the number of shards for the engine, defaults to 1.
-            As a general guideline, use 1 shard per 1 GB of data.
-        :type shards: int, optional
-        :param replicas: the number of replicas, defaults to 1.
-            Use at least 2 replicas if you need high availability (99.99% uptime) for querying.
-            For every 100 QPS your service needs to support, provision a replica.
-        :type replicas: int, optional
-        :param node_type: type of node to schedule the workloads on e.g. "STANDARD", "COMPUTE"
-        :type node_type: NodeType, optional
-        :param gateway_replicas: number of replicas of both the gateway and the aggregator.
-        :type gateway_replicas: int, optional
-        """
         super().__init__(gateway_replicas=gateway_replicas)
         self.preprocessors = {
             "read": [],
@@ -147,10 +187,20 @@ class IndexGraph(Graph):
         self.postprocessors = []
 
         # The engine and the aggregator must be specified for an index service
-        self.engine = self._default_engine(engine_type, metric=metric, replicas=replicas, shards=shards,
-                                           name="engine", node_type=node_type)
-        self.aggregator = None if shards == 1 else self._default_aggregator(num_shards=shards, name="aggregator",
-                                                                            replicas=gateway_replicas)
+        self.engine = self._default_engine(
+            engine_type,
+            metric=metric,
+            replicas=replicas,
+            shards=shards,
+            name="engine",
+            node_type=node_type,
+            **engine_args
+        )
+        self.aggregator = (
+            None
+            if shards == 1
+            else self._default_aggregator(num_shards=shards, name="aggregator", replicas=gateway_replicas)
+        )
         self._update_graph()
 
     @sentry
