@@ -9,6 +9,7 @@ import shutil
 import re
 
 from pinecone.utils import hubify
+from pinecone.utils.sentry import sentry_decorator as sentry
 from pinecone.functions.model import HubFunction
 from pinecone.functions.model.preprocessor import Preprocessor
 from pinecone.functions.model.preprocessor.hub import HubPreprocessor
@@ -111,36 +112,42 @@ def _get_action_api():
     return ActionAPI(host=Config.CONTROLLER_HOST, api_key=Config.API_KEY)
 
 
+@sentry
 def get_login_cmd() -> str:
     """Returns CLI command for logging into Pinecone hub."""
     api = _get_hub_api()
     return "docker login -u {username} -p {password} {server}".format(**api.get_login())
 
 
+@sentry
 def list_repositories():
     """Shows all repositories."""
     api = _get_hub_api()
     return api.list_repositories()
 
 
+@sentry
 def create_repository(name):
     """Creates or unarchives a repository."""
     api = _get_hub_api()
     return api.create_repository(name)
 
 
+@sentry
 def delete_repository(name):
     """Archives a repository."""
     api = _get_hub_api()
     return api.delete_repository(name)
 
 
+@sentry
 def list_repository_tags(name):
     """Lists tags of a repository."""
     api = _get_hub_api()
     return api.list_repository_tags(name)
 
 
+@sentry
 def as_user_image(image):
     """Returns the image name prepended with the user name."""
     user_api = _get_action_api()
@@ -148,6 +155,7 @@ def as_user_image(image):
     return "{username}/{image}".format(**locals())
 
 
+@sentry
 def as_repo_image(image):
     """Returns the complete repository image URI."""
     registry = Config.HUB_REGISTRY.split("https://")[-1].split("https://")[-1]
@@ -197,6 +205,7 @@ class ImageBuilder:
     def tag(self):
         return self.image.split(":")[1]
 
+    @sentry
     def package(self, exist_ok=False):
         """Creates artifacts for building a Pinecone-compatible docker image.
 
@@ -265,6 +274,7 @@ COPY model.py ./model.py
 
         logger.info("Docker build artifacts are saved to {0}".format(self.build_path))
 
+    @sentry
     def get_build_cmd(self) -> str:
         """Returns the docker build command."""
         build_path = self.build_path.resolve()
@@ -278,6 +288,7 @@ COPY model.py ./model.py
         )
         return template.format(**locals())
 
+    @sentry
     def get_push_cmd(self) -> str:
         """Returns command to push to docker hub."""
 
