@@ -1,4 +1,5 @@
-from . import ZMQServlet, Socket, SocketType
+from . import Socket, SocketType
+from .servlet import ZMQServlet
 from pinecone.utils.constants import ZMQ_CONTROL_PORT
 from pinecone.utils import get_hostname
 from pinecone.protos import core_pb2
