@@ -28,7 +28,7 @@ def get_dns_hosts(socket_spec: Socket):
 
 class SocketWrapper:
 
-    def __init__(self, socket_spec: Socket, context: zmq.Context, native: bool):
+    def __init__(self, socket_spec: Socket, context: zmq.Context, native: bool, disable_loadbalance: bool = False):
         """
         :param socket:
         :param context:
@@ -45,7 +45,7 @@ class SocketWrapper:
         self.unused_sockets = set()
         self.sockets_read_event = asyncio.Event()
         self.executor = ThreadPoolExecutor()
-        if native or socket_spec.bind:
+        if native or socket_spec.bind or disable_loadbalance:
             self.socket = self.get_socket(socket_spec)
         else:
             self.init_dns_sockets(socket_spec)
@@ -120,7 +120,8 @@ class SocketWrapper:
 
             hosts_to_close = set(old_dns) - set(new_dns)
             hosts_to_open = set(new_dns) - set(old_dns)
-
+            if hosts_to_close or hosts_to_open:
+                logger.debug(f"closing {len(hosts_to_close)} sockets, opening {len(hosts_to_open)}")
             for entry in hosts_to_open:
                 if len(hosts_to_close) > 0:
                     host_to_disconnect = hosts_to_close.pop()
@@ -134,7 +135,6 @@ class SocketWrapper:
                     self.socket_pool[entry] = new_sock
 
             for entry in hosts_to_close:
-                logger.debug(f"closing socket {entry}")
                 sock_to_close = self.socket_pool.pop(entry)
                 sock_to_close.disconnect(self.get_conn_string(self.socket_for_host(entry)))
                 # connect to the host itself, so messages don't get dropped
