@@ -55,6 +55,11 @@ class Runnable:
     def memory_request(self) -> int:
         return 200
 
+    @property
+    def cpu_request(self) -> int:
+        """In 1/1000th of cpu"""
+        return 100
+
     @property
     def volume_request(self) -> Optional[int]:
         """
