@@ -22,25 +22,25 @@ def read_proto(log_file: BinaryIO, size: int):
         entry.ParseFromString(msg_bytes)
     except google.protobuf.message.DecodeError:
         logger.error(f"failed to load msg from WAL: {msg_bytes}")
-    return entry, msg_bytes
+    return entry, len(msg_bytes)
 
 
 def read_entry(log_file: BinaryIO):
     size = read_size(log_file)
-    entry, msg_bytes = read_proto(log_file, size)
+    entry, msg_size = read_proto(log_file, size)
     read_size(log_file)
-    return entry, msg_bytes
+    return entry, msg_size
 
 
-def read_entry_backwards(log_file: BinaryIO):
+def read_entry_backwards(log_file: BinaryIO) -> [core_pb2.Request, int]:
     if log_file.tell() == 0:
-        return core_pb2.Request(), b''
+        return core_pb2.Request(), 0
     log_file.seek(-SIZE_BYTES, os.SEEK_CUR)
     size = read_size(log_file)
     log_file.seek(-(SIZE_BYTES + size), os.SEEK_CUR)
-    entry, msg_bytes = read_proto(log_file, size)
+    entry, msg_size = read_proto(log_file, size)
     log_file.seek(-(SIZE_BYTES + size), os.SEEK_CUR)  # reset to end of previous entry
-    return entry, msg_bytes
+    return entry, msg_size
 
 
 def write_log_entry(log_file: BinaryIO, entry: core_pb2.Request):
@@ -56,8 +56,8 @@ def compact_log(log_path: str, tmp_log_path: str, end_file_offset: int):
             log_file.seek(end_file_offset)
             ids_seen = defaultdict(set)
             while True:
-                entry, msg_bytes = read_entry_backwards(log_file)
-                if msg_bytes == b'':
+                entry, msg_size = read_entry_backwards(log_file)
+                if msg_size == 0:
                     break
 
                 new_entry = core_pb2.Request()
